pub struct Args {Show 24 fields
pub prompt: Option<String>,
pub language: Option<String>,
pub output: Option<String>,
pub interactive: bool,
pub config: Option<String>,
pub model: Option<String>,
pub template: Option<String>,
pub temperature: f32,
pub max_tokens: u32,
pub char_limit: Option<usize>,
pub save: bool,
pub copy: bool,
pub preview: bool,
pub edit: Option<String>,
pub context: Option<String>,
pub context_glob: Vec<String>,
pub theme: String,
pub no_color: bool,
pub verbose: bool,
pub debug: bool,
pub extend_conversation: bool,
pub repeat_input: bool,
pub tool_mode: bool,
pub subcommand: Option<Subcommand>,
}Fields
prompt: Option<String>Code generation prompt
language: Option<String>Programming language (typescript, python, etc.)
output: Option<String>Output file path
interactive: boolInteractive mode (default when no prompt provided)
config: Option<String>Configuration file path
model: Option<String>Apple Foundation Model to use
template: Option<String>Prompt template name (from config)
temperature: f32Temperature for code generation (0-2)
max_tokens: u32Maximum tokens to generate
char_limit: Option<usize>Maximum number of characters to use for piped stdin and context
save: boolSave generated code to file
copy: boolCopy generated code to clipboard
preview: boolPreview generated code in terminal
edit: Option<String>Edit existing file with generated code
context: Option<String>Additional context for code generation
context_glob: Vec<String>Glob patterns for additional context files
theme: StringTerminal theme (light/dark)
no_color: boolDisable colored output
verbose: boolVerbose output
debug: boolDebug mode
extend_conversation: boolExtend previous conversation instead of starting a new one
repeat_input: boolRepeat input before output (useful for editor integration)
tool_mode: boolRaw/tool mode: print plain output without preview formatting
subcommand: Option<Subcommand>Trait Implementations
Sourceimpl Args for Args
impl Args for Args
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Args
impl CommandFactory for Args
Sourceimpl FromArgMatches for Args
impl FromArgMatches for Args
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Args
impl Parser for Args
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)